@@ -122,10 +122,12 @@ class SemanticPredictabilityAnalyzer:
 
 
 
-    def disambiguate_sense(self,word,cat,context,to_string=False):
+    def disambiguate_sense(self,word,cat,prev_context,post_context,to_string=False):
         synsets = self.wn.synsets(word,pos=cat)
         if len(synsets) == 0:
             return None
+        prev_words = self.uni_analyze(prev_context)[-5:]
+        foll_words = self.uni_analyze(foll_context)[:5]
         best_sense = synsets[0]
         best_score = 0
         for s in synsets:
@@ -205,6 +207,9 @@ def evaluate_sentences():
             s['bag_ngrams_idf'] = ngram_idf_analyzer.get_semantic_predictability(word.replace('#','.'),map(lambda x: x.replace('#','.'),context))
             f.write('\t'.join([str(s[x]) for x in head]))
 
+def try_semeval():
+    ngram_idf_analyzer = SemanticPredictabilityAnalyzer(ngram=True,use_idf=True)
+
 if __name__ == '__main__':
     evaluate_sentences()
     #t = get_semantic_predictability('jaguar.n.1',['leopard.n.2'],ngram=True)
